# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2


class WarehouseServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.WarehouseCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseCreate",
            request_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseCreateResponse.FromString,
        )
        self.WarehouseRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseRead",
            request_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseReadResponse.FromString,
        )
        self.WarehouseUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseUpdate",
            request_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseUpdateResponse.FromString,
        )
        self.WarehouseDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseDelete",
            request_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseDeleteResponse.FromString,
        )


class WarehouseServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def WarehouseCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def WarehouseDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_WarehouseServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "WarehouseCreate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseCreate,
            request_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseCreateResponse.SerializeToString,
        ),
        "WarehouseRead": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseRead,
            request_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseReadResponse.SerializeToString,
        ),
        "WarehouseUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseUpdate,
            request_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseUpdateResponse.SerializeToString,
        ),
        "WarehouseDelete": grpc.unary_unary_rpc_method_handler(
            servicer.WarehouseDelete,
            request_deserializer=v1_dot_rules_dot_warehouse__pb2.WarehouseDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_warehouse__pb2.WarehouseDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.warehouse.WarehouseService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class WarehouseService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def WarehouseCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseCreate",
            v1_dot_rules_dot_warehouse__pb2.WarehouseCreateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__pb2.WarehouseCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseRead",
            v1_dot_rules_dot_warehouse__pb2.WarehouseReadRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__pb2.WarehouseReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseUpdate",
            v1_dot_rules_dot_warehouse__pb2.WarehouseUpdateRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__pb2.WarehouseUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def WarehouseDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.warehouse.WarehouseService/WarehouseDelete",
            v1_dot_rules_dot_warehouse__pb2.WarehouseDeleteRequest.SerializeToString,
            v1_dot_rules_dot_warehouse__pb2.WarehouseDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Language(_message.Message):
    __slots__ = [
        "id",
        "name",
        "code",
        "code_iso",
        "direction",
        "date_format",
        "time_format",
        "decimal_point",
        "thousands_separator",
        "grouping",
        "week_start",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_ISO_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    DATE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    TIME_FORMAT_FIELD_NUMBER: _ClassVar[int]
    DECIMAL_POINT_FIELD_NUMBER: _ClassVar[int]
    THOUSANDS_SEPARATOR_FIELD_NUMBER: _ClassVar[int]
    GROUPING_FIELD_NUMBER: _ClassVar[int]
    WEEK_START_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    code: str
    code_iso: str
    direction: str
    date_format: str
    time_format: str
    decimal_point: str
    thousands_separator: str
    grouping: str
    week_start: str
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        code_iso: _Optional[str] = ...,
        direction: _Optional[str] = ...,
        date_format: _Optional[str] = ...,
        time_format: _Optional[str] = ...,
        decimal_point: _Optional[str] = ...,
        thousands_separator: _Optional[str] = ...,
        grouping: _Optional[str] = ...,
        week_start: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class LanguageAddRequest(_message.Message):
    __slots__ = [
        "name",
        "code",
        "code_iso",
        "direction",
        "date_format",
        "time_format",
        "decimal_point",
        "thousands_separator",
        "grouping",
        "week_start",
        "active",
        "context",
    ]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_ISO_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    DATE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    TIME_FORMAT_FIELD_NUMBER: _ClassVar[int]
    DECIMAL_POINT_FIELD_NUMBER: _ClassVar[int]
    THOUSANDS_SEPARATOR_FIELD_NUMBER: _ClassVar[int]
    GROUPING_FIELD_NUMBER: _ClassVar[int]
    WEEK_START_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    code_iso: str
    direction: str
    date_format: str
    time_format: str
    decimal_point: str
    thousands_separator: str
    grouping: str
    week_start: str
    active: _wrappers_pb2.BoolValue
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        code_iso: _Optional[str] = ...,
        direction: _Optional[str] = ...,
        date_format: _Optional[str] = ...,
        time_format: _Optional[str] = ...,
        decimal_point: _Optional[str] = ...,
        thousands_separator: _Optional[str] = ...,
        grouping: _Optional[str] = ...,
        week_start: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class LanguageAddResponse(_message.Message):
    __slots__ = ["response_standard", "language"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    language: Language
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        language: _Optional[_Union[Language, _Mapping]] = ...,
    ) -> None: ...

class LanguageReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class LanguageReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "languages"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    LANGUAGES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    languages: _containers.RepeatedCompositeFieldContainer[Language]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        languages: _Optional[_Iterable[_Union[Language, _Mapping]]] = ...,
    ) -> None: ...

class LanguageUpdateRequest(_message.Message):
    __slots__ = ["language", "context"]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    language: Language
    context: _base_pb2.Context
    def __init__(
        self,
        language: _Optional[_Union[Language, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class LanguageUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "language"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    LANGUAGE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    language: Language
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        language: _Optional[_Union[Language, _Mapping]] = ...,
    ) -> None: ...

class LanguageDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class LanguageDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



import json
import typing
from collections import Counter

from bson.errors import InvalidId
from bson.objectid import ObjectId
from marshmallow import Schema, ValidationError, fields, missing, validates_schema
from marshmallow.exceptions import ValidationError


class ContextSchema(Schema):
    tenant = fields.String(required=True)
    user = fields.String(required=True)


class Context(Schema):
    context = fields.Nested(ContextSchema, required=True)


class BaseSchema(Context, Schema):
    active = fields.Boolean()


class PostgresBaseSchema(BaseSchema):
    def load(self, data, *args, **kwargs):
        data = super().load(data, *args, **kwargs)
        context = data.pop("context", {})
        data["tenant"] = context.get("tenant")
        data["updated_by"] = context.get("user")
        return data


class BaseObjectSchema(Schema):
    code = fields.String(required=True)
    code_name = fields.String(required=True)


def oid_isval(val: typing.Any) -> bool:
    """
    oid_isval [summary]

    Parameters
    ----------
    val : {Any}
        Value to be assessed if its an ObjectId

    Returns
    ----------
    val : bool
        True if val is an ObjectId, otherwise false
    """
    if ObjectId.is_valid(val):
        return val


def ensure_objid_type(val: typing.Union[bytes, str, ObjectId]) -> ObjectId:
    """
    Ensures that the value being passed is return as an ObjectId and is a valid ObjectId

    Parameters
    ----------
    val : Union[bytes, str, ObjectId]
        The value to be ensured or converted into an ObjectId and is a valid ObjectId

    Returns
    ----------
    val : ObjectId
        Value of type ObjectId

    Raises
    ----------
    ValidationError: Exception
        If it's not an ObjectId or can't be converted into an ObjectId, raise an error.

    """
    try:
        # If it's already an ObjectId and it's a valid ObjectId, return it
        if isinstance(val, ObjectId) and oid_isval(val):
            return val

        # Otherwise, if it's a bytes object, decode it and turn it into a string
        elif isinstance(val, bytes):
            val = ObjectId(str(val.decode("utf-8")))

        # Otherwise, if it's a string, turn it into an ObjectId and check that it's valid
        elif isinstance(val, str):
            val = ObjectId(val)

        # Check to see if the converted value is a valid objectId
        if oid_isval(val):
            return val
    except InvalidId as error:
        raise ValidationError(json.loads(json.dumps(f"{error}")))


class ObjectIdField(fields.Field):
    """Custom field for ObjectIds."""

    # Default error messages
    default_error_messages = {"invalid_ObjectId": "Not a valid ObjectId."}

    def _serialize(self, value, attr, obj, **kwargs) -> typing.Optional[ObjectId]:
        if value is None:
            return None
        return ensure_objid_type(value)

    def _deserialize(self, value, attr, data, **kwargs):
        if value is None:
            return missing
        if not isinstance(value, (ObjectId, str, bytes)):
            raise self.make_error("_deserialize: Not a invalid ObjectId")
        try:
            return ensure_objid_type(value)
        except UnicodeDecodeError as error:
            raise self.make_error("invalid_utf8") from error
        except (ValueError, AttributeError, TypeError) as error:
            raise ValidationError("ObjectIds must be a 12-byte input or a 24-character hex string") from error


class MicroServiceValidator(Context, Schema):
    name = fields.String(required=True)
    code = fields.String(required=True)
    tenant_code = fields.String(required=True)
    description = fields.String(required=True)
    version = fields.String(required=True)
    author = fields.String(required=True)
    summary = fields.String(required=True)
    category = fields.String(required=True)
    depends = fields.List(fields.String())
    data = fields.List(fields.String())

    def __init__(self, base_app, micro_data, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.base_app = base_app
        self.micro_data = micro_data

    @validates_schema
    def validate_data(self, data, *args, **kwargs):
        if elt := self._duplicate_elements(data.get("data", [])):
            raise ValidationError(f"Duplicate elements in data {elt}")
        list_path = []
        for path in data.get("data", []):
            file = self.base_app / path
            if not file.exists():
                list_path.append(path)
        if list_path:
            raise ValidationError(f"File not found {list_path}")

    def _duplicate_elements(self, data):
        return [item for item, count in Counter(data).items() if count > 1]

    def load(self, data, *args, **kwargs):
        data = super().load(data, *args, **kwargs)
        list_dict = []
        for path in data.get("data", []):
            md = next((x for x in self.micro_data if x.get("path") == path), None)
            if not md:
                list_dict.append({"path": path, "load": False})
        data["data"] = self.micro_data + list_dict
        return data



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_price.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1dv1/rules/delivery_price.proto\x12(pro.omni.oms.api.v1.rules.delivery_price\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a\x18v1/rules/warehouse.proto"\xb8\x03\n\rDeliveryPrice\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12V\n\x13\x64\x65livery_method_ids\x18\x03 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x45\n\rwarehouse_ids\x18\x04 \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12\x1d\n\x15locality_available_id\x18\x05 \x01(\t\x12\x45\n\ttime_type\x18\x06 \x01(\x0e\x32\x32.pro.omni.oms.api.v1.rules.delivery_price.TimeType\x12\x11\n\tvalue_min\x18\x07 \x01(\t\x12\x11\n\tvalue_max\x18\x08 \x01(\t\x12\x11\n\tinversely\x18\t \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12?\n\x0cobject_audit\x18\x0b \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x81\x02\n\x1a\x44\x65liveryPriceCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x02 \x01(\t\x12\x45\n\ttime_type\x18\x03 \x01(\x0e\x32\x32.pro.omni.oms.api.v1.rules.delivery_price.TimeType\x12\x11\n\tvalue_min\x18\x04 \x01(\t\x12\x11\n\tvalue_max\x18\x05 \x01(\t\x12\x11\n\tinversely\x18\x06 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1b\x44\x65liveryPriceCreateResponse\x12O\n\x0e\x64\x65livery_price\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPrice\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf6\x02\n\x18\x44\x65liveryPriceReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf3\x01\n\x19\x44\x65liveryPriceReadResponse\x12P\n\x0f\x64\x65livery_prices\x18\x01 \x03(\x0b\x32\x37.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPrice\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa5\x01\n\x1a\x44\x65liveryPriceUpdateRequest\x12O\n\x0e\x64\x65livery_price\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPrice\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1b\x44\x65liveryPriceUpdateResponse\x12O\n\x0e\x64\x65livery_price\x18\x01 \x01(\x0b\x32\x37.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPrice\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"`\n\x1a\x44\x65liveryPriceDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"h\n\x1b\x44\x65liveryPriceDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard*9\n\x08TimeType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07MINUTES\x10\x01\x12\t\n\x05HOURS\x10\x02\x12\x08\n\x04\x44\x41YS\x10\x03\x32\xac\x05\n\x14\x44\x65liveryPriceService\x12\xa4\x01\n\x13\x44\x65liveryPriceCreate\x12\x44.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceCreateRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceCreateResponse"\x00\x12\x9e\x01\n\x11\x44\x65liveryPriceRead\x12\x42.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceReadRequest\x1a\x43.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceReadResponse"\x00\x12\xa4\x01\n\x13\x44\x65liveryPriceUpdate\x12\x44.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceUpdateRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceUpdateResponse"\x00\x12\xa4\x01\n\x13\x44\x65liveryPriceDelete\x12\x44.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceDeleteRequest\x1a\x45.pro.omni.oms.api.v1.rules.delivery_price.DeliveryPriceDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_price_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TIMETYPE"]._serialized_start = 2226
    _globals["_TIMETYPE"]._serialized_end = 2283
    _globals["_DELIVERYPRICE"]._serialized_start = 153
    _globals["_DELIVERYPRICE"]._serialized_end = 593
    _globals["_DELIVERYPRICECREATEREQUEST"]._serialized_start = 596
    _globals["_DELIVERYPRICECREATEREQUEST"]._serialized_end = 853
    _globals["_DELIVERYPRICECREATERESPONSE"]._serialized_start = 856
    _globals["_DELIVERYPRICECREATERESPONSE"]._serialized_end = 1041
    _globals["_DELIVERYPRICEREADREQUEST"]._serialized_start = 1044
    _globals["_DELIVERYPRICEREADREQUEST"]._serialized_end = 1418
    _globals["_DELIVERYPRICEREADRESPONSE"]._serialized_start = 1421
    _globals["_DELIVERYPRICEREADRESPONSE"]._serialized_end = 1664
    _globals["_DELIVERYPRICEUPDATEREQUEST"]._serialized_start = 1667
    _globals["_DELIVERYPRICEUPDATEREQUEST"]._serialized_end = 1832
    _globals["_DELIVERYPRICEUPDATERESPONSE"]._serialized_start = 1835
    _globals["_DELIVERYPRICEUPDATERESPONSE"]._serialized_end = 2020
    _globals["_DELIVERYPRICEDELETEREQUEST"]._serialized_start = 2022
    _globals["_DELIVERYPRICEDELETEREQUEST"]._serialized_end = 2118
    _globals["_DELIVERYPRICEDELETERESPONSE"]._serialized_start = 2120
    _globals["_DELIVERYPRICEDELETERESPONSE"]._serialized_end = 2224
    _globals["_DELIVERYPRICESERVICE"]._serialized_start = 2286
    _globals["_DELIVERYPRICESERVICE"]._serialized_end = 2970
# @@protoc_insertion_point(module_scope)



from enum import Enum

from mongoengine.fields import EmbeddedDocumentField, ReferenceField
from peewee import ForeignKeyField


class Descriptor(object):
    @staticmethod
    def describe_mongo_model(model):
        description = {
            "model": model.__name__,
            "class_name": f"{model.__module__}.{model.__name__}",
            "name": model._meta.get("collection"),
            "fields": [],
        }
        for field_name, field in model._fields.items():
            field_info = {
                "name": field_name,
                "code": field_name,
                "type": field.__class__.__name__,
                "size": field.max_length if hasattr(field, "max_length") else None,
                "required": field.required,
                "relation": field.document_type.__name__ if isinstance(field, ReferenceField) else None,
            }

            # If the field is an EmbeddedDocumentField, get its fields as well
            if isinstance(field, EmbeddedDocumentField):
                embedded_model = field.document_type_obj
                embedded_fields = Descriptor.describe_mongo_model(embedded_model)
                field_info["embedded_fields"] = embedded_fields["fields"]

            # if the field is a Enum, add options values
            if hasattr(field, "choices") and field.choices:
                field_info["options"] = [x.value for x in field.choices]

            description["fields"].append(field_info)
        return description

    @staticmethod
    def describe_peewee_model(model):
        description = {
            "model": model.__name__,
            "class_name": f"{model.__module__}.{model.__name__}",
            "name": model.__name__.lower(),
            "fields": [],
        }
        for field_name, field in model._meta.fields.items():
            field_info = {
                "name": field_name,
                "code": field_name,
                "type": field.__class__.__name__,
                "size": field.max_length if hasattr(field, "max_length") else None,
                "required": not field.null,
                "relation": field.rel_model.__name__ if isinstance(field, ForeignKeyField) else None,
            }
            if hasattr(field, "choices") and field.choices:
                field_info["options"] = [option[0] for option in field.choices]
            description["fields"].append(field_info)
        return description



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/schedule_work.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import calendar_pb2 as v1_dot_rules_dot_calendar__pb2
from omni.pro.protos.v1.rules import schedule_work_line_pb2 as v1_dot_rules_dot_schedule__work__line__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1cv1/rules/schedule_work.proto\x12\'pro.omni.oms.api.v1.rules.schedule_work\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a!v1/rules/schedule_work_line.proto\x1a\x17v1/rules/calendar.proto"\xb5\x02\n\x0cScheduleWork\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x41\n\x0b\x63\x61lendar_id\x18\x03 \x01(\x0b\x32,.pro.omni.oms.api.v1.rules.calendar.Calendar\x12[\n\x13schedule_work_lines\x18\x04 \x03(\x0b\x32>.pro.omni.oms.api.v1.rules.schedule_work_line.ScheduleWorkLine\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"v\n\x19ScheduleWorkCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63\x61lendar_id\x18\x02 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aScheduleWorkCreateResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf5\x02\n\x17ScheduleWorkReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xef\x01\n\x18ScheduleWorkReadResponse\x12M\n\x0eschedules_work\x18\x01 \x03(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xa1\x01\n\x19ScheduleWorkUpdateRequest\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb5\x01\n\x1aScheduleWorkUpdateResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"_\n\x19ScheduleWorkDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"g\n\x1aScheduleWorkDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x8e\x01\n\x1a\x41\x64\x64ScheduleWorkLineRequest\x12\x18\n\x10schedule_work_id\x18\x01 \x01(\t\x12\x1e\n\x16schedule_work_line_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb6\x01\n\x1b\x41\x64\x64ScheduleWorkLineResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x91\x01\n\x1dRemoveScheduleWorkLineRequest\x12\x18\n\x10schedule_work_id\x18\x01 \x01(\t\x12\x1e\n\x16schedule_work_line_ids\x18\x02 \x03(\t\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xb9\x01\n\x1eRemoveScheduleWorkLineResponse\x12L\n\rschedule_work\x18\x01 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xea\x07\n\x13ScheduleWorkService\x12\x9f\x01\n\x12ScheduleWorkCreate\x12\x42.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkCreateRequest\x1a\x43.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkCreateResponse"\x00\x12\x99\x01\n\x10ScheduleWorkRead\x12@.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkReadRequest\x1a\x41.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkReadResponse"\x00\x12\x9f\x01\n\x12ScheduleWorkUpdate\x12\x42.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkUpdateRequest\x1a\x43.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkUpdateResponse"\x00\x12\x9f\x01\n\x12ScheduleWorkDelete\x12\x42.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkDeleteRequest\x1a\x43.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWorkDeleteResponse"\x00\x12\xa2\x01\n\x13\x41\x64\x64ScheduleWorkLine\x12\x43.pro.omni.oms.api.v1.rules.schedule_work.AddScheduleWorkLineRequest\x1a\x44.pro.omni.oms.api.v1.rules.schedule_work.AddScheduleWorkLineResponse"\x00\x12\xab\x01\n\x16RemoveScheduleWorkLine\x12\x46.pro.omni.oms.api.v1.rules.schedule_work.RemoveScheduleWorkLineRequest\x1aG.pro.omni.oms.api.v1.rules.schedule_work.RemoveScheduleWorkLineResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.schedule_work_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SCHEDULEWORK"]._serialized_start = 185
    _globals["_SCHEDULEWORK"]._serialized_end = 494
    _globals["_SCHEDULEWORKCREATEREQUEST"]._serialized_start = 496
    _globals["_SCHEDULEWORKCREATEREQUEST"]._serialized_end = 614
    _globals["_SCHEDULEWORKCREATERESPONSE"]._serialized_start = 617
    _globals["_SCHEDULEWORKCREATERESPONSE"]._serialized_end = 798
    _globals["_SCHEDULEWORKREADREQUEST"]._serialized_start = 801
    _globals["_SCHEDULEWORKREADREQUEST"]._serialized_end = 1174
    _globals["_SCHEDULEWORKREADRESPONSE"]._serialized_start = 1177
    _globals["_SCHEDULEWORKREADRESPONSE"]._serialized_end = 1416
    _globals["_SCHEDULEWORKUPDATEREQUEST"]._serialized_start = 1419
    _globals["_SCHEDULEWORKUPDATEREQUEST"]._serialized_end = 1580
    _globals["_SCHEDULEWORKUPDATERESPONSE"]._serialized_start = 1583
    _globals["_SCHEDULEWORKUPDATERESPONSE"]._serialized_end = 1764
    _globals["_SCHEDULEWORKDELETEREQUEST"]._serialized_start = 1766
    _globals["_SCHEDULEWORKDELETEREQUEST"]._serialized_end = 1861
    _globals["_SCHEDULEWORKDELETERESPONSE"]._serialized_start = 1863
    _globals["_SCHEDULEWORKDELETERESPONSE"]._serialized_end = 1966
    _globals["_ADDSCHEDULEWORKLINEREQUEST"]._serialized_start = 1969
    _globals["_ADDSCHEDULEWORKLINEREQUEST"]._serialized_end = 2111
    _globals["_ADDSCHEDULEWORKLINERESPONSE"]._serialized_start = 2114
    _globals["_ADDSCHEDULEWORKLINERESPONSE"]._serialized_end = 2296
    _globals["_REMOVESCHEDULEWORKLINEREQUEST"]._serialized_start = 2299
    _globals["_REMOVESCHEDULEWORKLINEREQUEST"]._serialized_end = 2444
    _globals["_REMOVESCHEDULEWORKLINERESPONSE"]._serialized_start = 2447
    _globals["_REMOVESCHEDULEWORKLINERESPONSE"]._serialized_end = 2632
    _globals["_SCHEDULEWORKSERVICE"]._serialized_start = 2635
    _globals["_SCHEDULEWORKSERVICE"]._serialized_end = 3637
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_time_warehouse.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n&v1/rules/delivery_time_warehouse.proto\x12\x31pro.omni.oms.api.v1.rules.delivery_time_warehouse\x1a\x11\x63ommon/base.proto"\xa4\x01\n\x15\x44\x65liveryTimeWarehouse\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x18\n\x10\x64\x65livery_time_id\x18\x02 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x03 \x01(\x05\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12?\n\x0cobject_audit\x18\x05 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x8c\x01\n"DeliveryTimeWarehouseCreateRequest\x12\x18\n\x10\x64\x65livery_time_id\x18\x01 \x01(\x05\x12\x14\n\x0cwarehouse_id\x18\x02 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x03 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdb\x01\n#DeliveryTimeWarehouseCreateResponse\x12i\n\x17\x64\x65livery_time_warehouse\x18\x01 \x01(\x0b\x32H.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xfe\x02\n DeliveryTimeWarehouseReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x94\x02\n!DeliveryTimeWarehouseReadResponse\x12i\n\x17\x64\x65livery_time_warehouse\x18\x01 \x03(\x0b\x32H.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouse\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xc7\x01\n"DeliveryTimeWarehouseUpdateRequest\x12i\n\x17\x64\x65livery_time_warehouse\x18\x01 \x01(\x0b\x32H.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouse\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdb\x01\n#DeliveryTimeWarehouseUpdateResponse\x12i\n\x17\x64\x65livery_time_warehouse\x18\x01 \x01(\x0b\x32H.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouse\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"h\n"DeliveryTimeWarehouseDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"p\n#DeliveryTimeWarehouseDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xdc\x06\n\x1c\x44\x65liveryTimeWarehouseService\x12\xce\x01\n\x1b\x44\x65liveryTimeWarehouseCreate\x12U.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseCreateRequest\x1aV.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseCreateResponse"\x00\x12\xc8\x01\n\x19\x44\x65liveryTimeWarehouseRead\x12S.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseReadRequest\x1aT.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseReadResponse"\x00\x12\xce\x01\n\x1b\x44\x65liveryTimeWarehouseUpdate\x12U.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseUpdateRequest\x1aV.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseUpdateResponse"\x00\x12\xce\x01\n\x1b\x44\x65liveryTimeWarehouseDelete\x12U.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseDeleteRequest\x1aV.pro.omni.oms.api.v1.rules.delivery_time_warehouse.DeliveryTimeWarehouseDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_time_warehouse_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYTIMEWAREHOUSE"]._serialized_start = 113
    _globals["_DELIVERYTIMEWAREHOUSE"]._serialized_end = 277
    _globals["_DELIVERYTIMEWAREHOUSECREATEREQUEST"]._serialized_start = 280
    _globals["_DELIVERYTIMEWAREHOUSECREATEREQUEST"]._serialized_end = 420
    _globals["_DELIVERYTIMEWAREHOUSECREATERESPONSE"]._serialized_start = 423
    _globals["_DELIVERYTIMEWAREHOUSECREATERESPONSE"]._serialized_end = 642
    _globals["_DELIVERYTIMEWAREHOUSEREADREQUEST"]._serialized_start = 645
    _globals["_DELIVERYTIMEWAREHOUSEREADREQUEST"]._serialized_end = 1027
    _globals["_DELIVERYTIMEWAREHOUSEREADRESPONSE"]._serialized_start = 1030
    _globals["_DELIVERYTIMEWAREHOUSEREADRESPONSE"]._serialized_end = 1306
    _globals["_DELIVERYTIMEWAREHOUSEUPDATEREQUEST"]._serialized_start = 1309
    _globals["_DELIVERYTIMEWAREHOUSEUPDATEREQUEST"]._serialized_end = 1508
    _globals["_DELIVERYTIMEWAREHOUSEUPDATERESPONSE"]._serialized_start = 1511
    _globals["_DELIVERYTIMEWAREHOUSEUPDATERESPONSE"]._serialized_end = 1730
    _globals["_DELIVERYTIMEWAREHOUSEDELETEREQUEST"]._serialized_start = 1732
    _globals["_DELIVERYTIMEWAREHOUSEDELETEREQUEST"]._serialized_end = 1836
    _globals["_DELIVERYTIMEWAREHOUSEDELETERESPONSE"]._serialized_start = 1838
    _globals["_DELIVERYTIMEWAREHOUSEDELETERESPONSE"]._serialized_end = 1950
    _globals["_DELIVERYTIMEWAREHOUSESERVICE"]._serialized_start = 1953
    _globals["_DELIVERYTIMEWAREHOUSESERVICE"]._serialized_end = 2813
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/route.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x14v1/stock/route.proto\x12\x1fpro.omni.oms.api.v1.stock.route\x1a\x11\x63ommon/base.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x9e\x03\n\x05Route\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08sequence\x18\x03 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x08 \x01(\x05\x12*\n\x06\x61\x63tive\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\n \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xea\x02\n\x12RouteCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08sequence\x18\x02 \x01(\x05\x12<\n\x18product_categ_selectable\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12product_selectable\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x36\n\x12packing_selectable\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x38\n\x14warehouse_selectable\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x14\n\x0cwarehouse_id\x18\x07 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x08 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13RouteCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05route\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route"\xee\x02\n\x10RouteReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xd1\x01\n\x11RouteReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x36\n\x06routes\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route"\x83\x01\n\x12RouteUpdateRequest\x12\x35\n\x05route\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x97\x01\n\x13RouteUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x35\n\x05route\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.stock.route.Route"X\n\x12RouteDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"`\n\x13RouteDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xf8\x03\n\x0cRouteService\x12z\n\x0bRouteCreate\x12\x33.pro.omni.oms.api.v1.stock.route.RouteCreateRequest\x1a\x34.pro.omni.oms.api.v1.stock.route.RouteCreateResponse"\x00\x12t\n\tRouteRead\x12\x31.pro.omni.oms.api.v1.stock.route.RouteReadRequest\x1a\x32.pro.omni.oms.api.v1.stock.route.RouteReadResponse"\x00\x12z\n\x0bRouteUpdate\x12\x33.pro.omni.oms.api.v1.stock.route.RouteUpdateRequest\x1a\x34.pro.omni.oms.api.v1.stock.route.RouteUpdateResponse"\x00\x12z\n\x0bRouteDelete\x12\x33.pro.omni.oms.api.v1.stock.route.RouteDeleteRequest\x1a\x34.pro.omni.oms.api.v1.stock.route.RouteDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.route_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_ROUTE"]._serialized_start = 139
    _globals["_ROUTE"]._serialized_end = 553
    _globals["_ROUTECREATEREQUEST"]._serialized_start = 556
    _globals["_ROUTECREATEREQUEST"]._serialized_end = 918
    _globals["_ROUTECREATERESPONSE"]._serialized_start = 921
    _globals["_ROUTECREATERESPONSE"]._serialized_end = 1072
    _globals["_ROUTEREADREQUEST"]._serialized_start = 1075
    _globals["_ROUTEREADREQUEST"]._serialized_end = 1441
    _globals["_ROUTEREADRESPONSE"]._serialized_start = 1444
    _globals["_ROUTEREADRESPONSE"]._serialized_end = 1653
    _globals["_ROUTEUPDATEREQUEST"]._serialized_start = 1656
    _globals["_ROUTEUPDATEREQUEST"]._serialized_end = 1787
    _globals["_ROUTEUPDATERESPONSE"]._serialized_start = 1790
    _globals["_ROUTEUPDATERESPONSE"]._serialized_end = 1941
    _globals["_ROUTEDELETEREQUEST"]._serialized_start = 1943
    _globals["_ROUTEDELETEREQUEST"]._serialized_end = 2031
    _globals["_ROUTEDELETERESPONSE"]._serialized_start = 2033
    _globals["_ROUTEDELETERESPONSE"]._serialized_end = 2129
    _globals["_ROUTESERVICE"]._serialized_start = 2132
    _globals["_ROUTESERVICE"]._serialized_end = 2636
# @@protoc_insertion_point(module_scope)



import re

from datetime import datetime

from google.protobuf.timestamp_pb2 import Timestamp
from mongoengine import BooleanField, DateTimeField, Document, EmbeddedDocument, EmbeddedDocumentField, StringField
from omni.pro.protos.common.base_pb2 import Context as ContextProto
from omni.pro.protos.common.base_pb2 import Object as ObjectProto
from omni.pro.protos.common.base_pb2 import ObjectAudit as AuditProto
from sqlalchemy import Boolean, DateTime, ForeignKey, String
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import DeclarativeBase, Mapped, declarative_mixin, declared_attr, mapped_column, relationship


class BaseEmbeddedDocument(EmbeddedDocument):
    meta = {
        "abstract": True,
        "strict": False,
    }

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError


class BaseObjectEmbeddedDocument(BaseEmbeddedDocument):
    code = StringField()
    code_name = StringField()
    meta = {
        "allow_inheritance": True,
    }

    def to_proto(self):
        return ObjectProto(
            code=self.code,
            code_name=self.code_name,
        )


class Audit(BaseEmbeddedDocument):
    created_at = DateTimeField(default=datetime.utcnow)
    created_by = StringField()
    updated_at = DateTimeField()
    updated_by = StringField()
    deleted_at = DateTimeField()
    deleted_by = StringField()

    def to_proto(self) -> AuditProto:
        create_at_ts = Timestamp()
        create_at_ts.FromDatetime(self.created_at)
        update_at_ts = Timestamp()
        update_at_ts.FromDatetime(self.updated_at)
        return AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            created_at=create_at_ts,
            updated_at=update_at_ts,
        )


class Context(BaseEmbeddedDocument):
    tenant = StringField()
    user = StringField()

    def to_proto(self) -> ContextProto:
        return ContextProto(
            tenant=self.tenant,
            user=self.user,
        )


class BaseDocument(Document):
    context = EmbeddedDocumentField(Context)
    audit = EmbeddedDocumentField(Audit)
    active = BooleanField(default=True)

    meta = {
        "abstract": True,
        "strict": False,
    }

    @classmethod
    @property
    def db(cls):
        return cls._get_db()

    def save(self, *args, **kwargs):
        if not self.context:
            self.context = Context()
        if not self.audit:
            self.audit = Audit(created_by=self.context.user)
        self.audit.updated_by = self.context.user
        self.audit.updated_at = datetime.utcnow()
        return super().save(*args, **kwargs)

    def to_proto(self, *args, **kwargs):
        raise NotImplementedError

    @classmethod
    def reference_list(cls):
        return [cls]


class BaseAuditEmbeddedDocument(BaseEmbeddedDocument):
    context = EmbeddedDocumentField(Context)
    audit = EmbeddedDocumentField(Audit)
    active = BooleanField(default=True)
    meta = {
        "abstract": True,
        "strict": False,
    }

    # TODO: Add a method to update the audit fields
    def save(self, *args, **kwargs):
        if not self.context:
            self.context = Context()
        if not self.audit:
            self.audit = Audit(created_by=self.context.user)
        self.audit.updated_by = self.context.user
        self.audit.updated_at = datetime.utcnow()
        return super().save(*args, **kwargs)


BaseAuditContextEmbeddedDocument = BaseAuditEmbeddedDocument


def set_created_by(context):
    params = context.get_current_parameters()
    if params.get("created_by") is None:
        return params.get("updated_by")
    return params.get("created_by")


class Base:
    """
    Base class provides foundational attributes and methods for database models.
    It includes common attributes such as 'id', 'active', and timestamp fields.
    It also provides methods for converting the model to its proto representation.
    """

    @staticmethod
    def _camel_to_snake(name):
        """
        Convert a CamelCase string to snake_case.

        Args:
            name (str): The CamelCase string.

        Returns:
            str: The converted snake_case string.
        """
        s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
        return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()

    @declared_attr
    def __tablename__(cls):
        """
        Generate a table name based on the class name.

        Returns:
            str: The table name in snake_case format.
        """
        return cls._camel_to_snake(cls.__name__)

    id: Mapped[int] = mapped_column(primary_key=True, autoincrement=True)
    active: Mapped[bool] = mapped_column(Boolean, default=True, nullable=False)
    tenant: Mapped[str] = mapped_column(String(30), nullable=False)
    created_by: Mapped[str] = mapped_column(String(50), default=set_created_by, nullable=False)
    updated_by: Mapped[str] = mapped_column(String(50), nullable=False)
    deleted_by: Mapped[str] = mapped_column(String(50), nullable=True)
    created_at: Mapped[datetime] = mapped_column(DateTime(), default=datetime.now, nullable=False)
    updated_at: Mapped[datetime] = mapped_column(
        DateTime(), default=datetime.now, onupdate=datetime.now, nullable=False
    )
    deleted_at: Mapped[datetime] = mapped_column(DateTime(), nullable=True)

    def create(self, session):
        """
        Add the current instance to the provided database session and flushes the session.

        Parameters:
        - session (Session): An instance of a database session, likely from SQLAlchemy.

        Returns:
        - self: Returns the instance after adding it to the session.

        Usage:
        instance = Base()
        instance.create(session)
        """
        session.add(self)
        session.flush()
        return self

    def update(self, session):
        """
        Flush the changes made to the current instance to the database through the provided session.

        This function assumes that the instance has been already added to the session or
        is being tracked by the session. The function will flush changes without committing them,
        allowing for further operations before a final commit.

        Parameters:
        - session (Session): An instance of a database session, likely from SQLAlchemy.

        Usage:
        instance.attribute = new_value
        instance.update(session)
        """
        session.flush()

    def delete(self, session):
        """
        Deletes the current instance from the database using the provided session.

        This function marks the instance for deletion in the session. Committing the session
        afterward will result in the instance being removed from the database.

        Parameters:
        - session (Session): An instance of a database session, likely from SQLAlchemy.

        Usage:
        instance.delete(session)
        """
        session.delete(self)

    def to_proto(self) -> AuditProto:
        """
        Convert the model instance to its proto representation.

        Returns:
            AuditProto: The proto representation of the model.
        """
        create_at_ts = Timestamp()
        create_at_ts.FromDatetime(self.created_at)
        update_at_ts = Timestamp()
        update_at_ts.FromDatetime(self.updated_at)
        audit_proto = AuditProto(
            created_by=self.created_by,
            updated_by=self.updated_by,
            created_at=create_at_ts,
            updated_at=update_at_ts,
        )
        if self.deleted_at:
            deleted_at_ts = Timestamp()
            deleted_at_ts.FromDatetime(self.deleted_at)
            audit_proto.deleted_at = deleted_at_ts

        return audit_proto

    def sync_data(self, *args, **kwargs):
        """
       Synchronize the data for the model instance.

       This method should be overridden in subclasses.

       Raises:
           NotImplementedError: If the method is not overridden in a subclass.
       """
        raise NotImplementedError

    def get_or_sync(self, *args, **kwargs):
        """
        Retrieve or synchronize the data for the model instance.

        This method should be overridden in subclasses.

        Raises:
            NotImplementedError: If the method is not overridden in a subclass.
        """
        raise NotImplementedError

    def get_document_info(self, *args, **kwargs):
        """
        Retrieve document-related information for the model instance.

        This method should be overridden in subclasses.

        Raises:
            NotImplementedError: If the method is not overridden in a subclass.
        """
        raise NotImplementedError


BaseModel = declarative_base(cls=Base)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/stock/sequence.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x17v1/stock/sequence.proto\x12"pro.omni.oms.api.v1.stock.sequence\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb8\x01\n\x08Sequence\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x17\n\x0fsequence_doc_id\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x84\x01\n\x15SequenceCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x17\n\x0fsequence_doc_id\x18\x03 \x01(\t\x12\x36\n\x07\x63ontext\x18\x04 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16SequenceCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12>\n\x08sequence\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.sequence.Sequence"\xf1\x02\n\x13SequenceReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x14SequenceReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12?\n\tsequences\x18\x03 \x03(\x0b\x32,.pro.omni.oms.api.v1.stock.sequence.Sequence"\x8f\x01\n\x15SequenceUpdateRequest\x12>\n\x08sequence\x18\x01 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.sequence.Sequence\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x16SequenceUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12>\n\x08sequence\x18\x02 \x01(\x0b\x32,.pro.omni.oms.api.v1.stock.sequence.Sequence"[\n\x15SequenceDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"c\n\x16SequenceDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xbb\x04\n\x0fSequenceService\x12\x89\x01\n\x0eSequenceCreate\x12\x39.pro.omni.oms.api.v1.stock.sequence.SequenceCreateRequest\x1a:.pro.omni.oms.api.v1.stock.sequence.SequenceCreateResponse"\x00\x12\x83\x01\n\x0cSequenceRead\x12\x37.pro.omni.oms.api.v1.stock.sequence.SequenceReadRequest\x1a\x38.pro.omni.oms.api.v1.stock.sequence.SequenceReadResponse"\x00\x12\x89\x01\n\x0eSequenceUpdate\x12\x39.pro.omni.oms.api.v1.stock.sequence.SequenceUpdateRequest\x1a:.pro.omni.oms.api.v1.stock.sequence.SequenceUpdateResponse"\x00\x12\x89\x01\n\x0eSequenceDelete\x12\x39.pro.omni.oms.api.v1.stock.sequence.SequenceDeleteRequest\x1a:.pro.omni.oms.api.v1.stock.sequence.SequenceDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.stock.sequence_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_SEQUENCE"]._serialized_start = 115
    _globals["_SEQUENCE"]._serialized_end = 299
    _globals["_SEQUENCECREATEREQUEST"]._serialized_start = 302
    _globals["_SEQUENCECREATEREQUEST"]._serialized_end = 434
    _globals["_SEQUENCECREATERESPONSE"]._serialized_start = 437
    _globals["_SEQUENCECREATERESPONSE"]._serialized_end = 600
    _globals["_SEQUENCEREADREQUEST"]._serialized_start = 603
    _globals["_SEQUENCEREADREQUEST"]._serialized_end = 972
    _globals["_SEQUENCEREADRESPONSE"]._serialized_start = 975
    _globals["_SEQUENCEREADRESPONSE"]._serialized_end = 1196
    _globals["_SEQUENCEUPDATEREQUEST"]._serialized_start = 1199
    _globals["_SEQUENCEUPDATEREQUEST"]._serialized_end = 1342
    _globals["_SEQUENCEUPDATERESPONSE"]._serialized_start = 1345
    _globals["_SEQUENCEUPDATERESPONSE"]._serialized_end = 1508
    _globals["_SEQUENCEDELETEREQUEST"]._serialized_start = 1510
    _globals["_SEQUENCEDELETEREQUEST"]._serialized_end = 1601
    _globals["_SEQUENCEDELETERESPONSE"]._serialized_start = 1603
    _globals["_SEQUENCEDELETERESPONSE"]._serialized_end = 1702
    _globals["_SEQUENCESERVICE"]._serialized_start = 1705
    _globals["_SEQUENCESERVICE"]._serialized_end = 2276
# @@protoc_insertion_point(module_scope)



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from omni.pro.protos.common import base_pb2 as _base_pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as _delivery_method_pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as _warehouse_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class TimeType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = []
    UNKNOWN: _ClassVar[TimeType]
    MINUTES: _ClassVar[TimeType]
    HOURS: _ClassVar[TimeType]
    DAYS: _ClassVar[TimeType]

UNKNOWN: TimeType
MINUTES: TimeType
HOURS: TimeType
DAYS: TimeType

class DeliveryShipper(_message.Message):
    __slots__ = [
        "id",
        "name",
        "delivery_method_ids",
        "warehouse_ids",
        "locality_available_id",
        "time_type",
        "value_min",
        "value_max",
        "inversely",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DELIVERY_METHOD_IDS_FIELD_NUMBER: _ClassVar[int]
    WAREHOUSE_IDS_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_ID_FIELD_NUMBER: _ClassVar[int]
    TIME_TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_MIN_FIELD_NUMBER: _ClassVar[int]
    VALUE_MAX_FIELD_NUMBER: _ClassVar[int]
    INVERSELY_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    delivery_method_ids: _containers.RepeatedCompositeFieldContainer[_delivery_method_pb2.DeliveryMethod]
    warehouse_ids: _containers.RepeatedCompositeFieldContainer[_warehouse_pb2.Warehouse]
    locality_available_id: str
    time_type: TimeType
    value_min: str
    value_max: str
    inversely: bool
    active: bool
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        delivery_method_ids: _Optional[_Iterable[_Union[_delivery_method_pb2.DeliveryMethod, _Mapping]]] = ...,
        warehouse_ids: _Optional[_Iterable[_Union[_warehouse_pb2.Warehouse, _Mapping]]] = ...,
        locality_available_id: _Optional[str] = ...,
        time_type: _Optional[_Union[TimeType, str]] = ...,
        value_min: _Optional[str] = ...,
        value_max: _Optional[str] = ...,
        inversely: bool = ...,
        active: bool = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperCreateRequest(_message.Message):
    __slots__ = ["name", "locality_available_id", "time_type", "value_min", "value_max", "inversely", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    LOCALITY_AVAILABLE_ID_FIELD_NUMBER: _ClassVar[int]
    TIME_TYPE_FIELD_NUMBER: _ClassVar[int]
    VALUE_MIN_FIELD_NUMBER: _ClassVar[int]
    VALUE_MAX_FIELD_NUMBER: _ClassVar[int]
    INVERSELY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    locality_available_id: str
    time_type: TimeType
    value_min: str
    value_max: str
    inversely: bool
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        locality_available_id: _Optional[str] = ...,
        time_type: _Optional[_Union[TimeType, str]] = ...,
        value_min: _Optional[str] = ...,
        value_max: _Optional[str] = ...,
        inversely: bool = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperCreateResponse(_message.Message):
    __slots__ = ["delivery_shipper", "response_standard"]
    DELIVERY_SHIPPER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_shipper: DeliveryShipper
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_shipper: _Optional[_Union[DeliveryShipper, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: int
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperReadResponse(_message.Message):
    __slots__ = ["delivery_shippers", "meta_data", "response_standard"]
    DELIVERY_SHIPPERS_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_shippers: _containers.RepeatedCompositeFieldContainer[DeliveryShipper]
    meta_data: _base_pb2.MetaData
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_shippers: _Optional[_Iterable[_Union[DeliveryShipper, _Mapping]]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperUpdateRequest(_message.Message):
    __slots__ = ["delivery_shipper", "context"]
    DELIVERY_SHIPPER_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    delivery_shipper: DeliveryShipper
    context: _base_pb2.Context
    def __init__(
        self,
        delivery_shipper: _Optional[_Union[DeliveryShipper, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperUpdateResponse(_message.Message):
    __slots__ = ["delivery_shipper", "response_standard"]
    DELIVERY_SHIPPER_FIELD_NUMBER: _ClassVar[int]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    delivery_shipper: DeliveryShipper
    response_standard: _base_pb2.ResponseStandard
    def __init__(
        self,
        delivery_shipper: _Optional[_Union[DeliveryShipper, _Mapping]] = ...,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
    ) -> None: ...

class DeliveryShipperDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: int
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[int] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class DeliveryShipperDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



class NotFoundError(Exception):
    def __init__(
        self,
        message: str | list | dict,
        **kwargs,
    ):
        self.messages = [message] if isinstance(message, (str, bytes)) else message
        self.kwargs = kwargs
        super().__init__(message)



import os

from omni.pro.util import parse_bool


class Config(object):
    DEBUG = parse_bool(os.environ.get("DEBUG")) or False
    API_REFLECTION = parse_bool(os.environ.get("API_REFLECTION")) or False
    TESTING = parse_bool(os.environ.get("TESTING")) or False

    GRPC_PORT = os.environ.get("GRPC_PORT") or 50051
    GRPC_MAX_WORKERS = int(os.environ.get("GRPC_MAX_WORKERS") or 10)
    SERVICE_ID = os.environ.get("SERVICE_ID")
    REDIS_HOST = os.environ.get("REDIS_HOST") or "localhost"
    REDIS_PORT = int(os.environ.get("REDIS_PORT") or 6379)
    REDIS_DB = int(os.environ.get("REDIS_DB") or 0)
    AWS_ACCESS_KEY_ID = os.environ.get("AWS_KEY")
    AWS_SECRET_ACCESS_KEY = os.environ.get("AWS_SECRET")
    REGION_NAME = os.environ.get("REGION_NAME") or "us-east-1"
    NAMESPACE_NAME = os.environ.get("NAMESPACE_NAME")
    SERVICE_NAME = os.environ.get("SERVICE_NAME")
    USER_MS_PORT = os.environ.get("USER_MS_PORT") or 50052
    USER_MS_HOST = os.environ.get("USER_MS_HOST") or "localhost"
    SERVICE_NAME_BALANCER = os.environ.get("SERVICE_NAME_BALANCER")
    SAAS_MS_USER = os.environ.get("SAAS_MS_USER")
    SAAS_MS_CATALOG = os.environ.get("SAAS_MS_CATALOG")
    SAAS_MS_UTILITIES = os.environ.get("SAAS_MS_UTILITIES")
    SAAS_MS_STOCK = os.environ.get("SAAS_MS_STOCK")
    SAAS_MS_CLIENT = os.environ.get("SAAS_MS_CLIENT")
    TENANT_POSTGRESQL_URL = os.environ.get("TENANT_POSTGRESQL_URL")



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.rules import (
    delivery_time_delivery_method_pb2 as v1_dot_rules_dot_delivery__time__delivery__method__pb2,
)


class DeliveryTimeDeliveryMethodServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DeliveryTimeDeliveryMethodCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodCreate",
            request_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodCreateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodCreateResponse.FromString,
        )
        self.DeliveryTimeDeliveryMethodRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodRead",
            request_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodReadRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodReadResponse.FromString,
        )
        self.DeliveryTimeDeliveryMethodUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodUpdate",
            request_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodUpdateResponse.FromString,
        )
        self.DeliveryTimeDeliveryMethodDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodDelete",
            request_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodDeleteResponse.FromString,
        )


class DeliveryTimeDeliveryMethodServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def DeliveryTimeDeliveryMethodCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeDeliveryMethodRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeDeliveryMethodUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeliveryTimeDeliveryMethodDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DeliveryTimeDeliveryMethodServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "DeliveryTimeDeliveryMethodCreate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeDeliveryMethodCreate,
            request_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodCreateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodCreateResponse.SerializeToString,
        ),
        "DeliveryTimeDeliveryMethodRead": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeDeliveryMethodRead,
            request_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodReadRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodReadResponse.SerializeToString,
        ),
        "DeliveryTimeDeliveryMethodUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeDeliveryMethodUpdate,
            request_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodUpdateRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodUpdateResponse.SerializeToString,
        ),
        "DeliveryTimeDeliveryMethodDelete": grpc.unary_unary_rpc_method_handler(
            servicer.DeliveryTimeDeliveryMethodDelete,
            request_deserializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodDeleteRequest.FromString,
            response_serializer=v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DeliveryTimeDeliveryMethodService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def DeliveryTimeDeliveryMethodCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodCreate",
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodCreateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeDeliveryMethodRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodRead",
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodReadRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeDeliveryMethodUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodUpdate",
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodUpdateRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeliveryTimeDeliveryMethodDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.rules.delivery_time_delivery_method.DeliveryTimeDeliveryMethodService/DeliveryTimeDeliveryMethodDelete",
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodDeleteRequest.SerializeToString,
            v1_dot_rules_dot_delivery__time__delivery__method__pb2.DeliveryTimeDeliveryMethodDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )



from typing import ClassVar as _ClassVar
from typing import Iterable as _Iterable
from typing import Mapping as _Mapping
from typing import Optional as _Optional
from typing import Union as _Union

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from omni.pro.protos.common import base_pb2 as _base_pb2

DESCRIPTOR: _descriptor.FileDescriptor

class Family(_message.Message):
    __slots__ = [
        "id",
        "name",
        "code",
        "attribute_as_label",
        "attribute_as_image",
        "variants",
        "groups",
        "active",
        "object_audit",
    ]
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_AS_LABEL_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_AS_IMAGE_FIELD_NUMBER: _ClassVar[int]
    VARIANTS_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_AUDIT_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    code: str
    attribute_as_label: Attribute
    attribute_as_image: Attribute
    variants: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    groups: _containers.RepeatedCompositeFieldContainer[_struct_pb2.Struct]
    active: _wrappers_pb2.BoolValue
    object_audit: _base_pb2.ObjectAudit
    def __init__(
        self,
        id: _Optional[str] = ...,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        attribute_as_label: _Optional[_Union[Attribute, _Mapping]] = ...,
        attribute_as_image: _Optional[_Union[Attribute, _Mapping]] = ...,
        variants: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        groups: _Optional[_Iterable[_Union[_struct_pb2.Struct, _Mapping]]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        object_audit: _Optional[_Union[_base_pb2.ObjectAudit, _Mapping]] = ...,
    ) -> None: ...

class FamilyCreateRequest(_message.Message):
    __slots__ = ["name", "code", "attribute_as_label", "attribute_as_image", "context"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_AS_LABEL_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_AS_IMAGE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    name: str
    code: str
    attribute_as_label: str
    attribute_as_image: str
    context: _base_pb2.Context
    def __init__(
        self,
        name: _Optional[str] = ...,
        code: _Optional[str] = ...,
        attribute_as_label: _Optional[str] = ...,
        attribute_as_image: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class FamilyCreateResponse(_message.Message):
    __slots__ = ["response_standard", "family"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    family: Family
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        family: _Optional[_Union[Family, _Mapping]] = ...,
    ) -> None: ...

class FamilyReadRequest(_message.Message):
    __slots__ = ["group_by", "sort_by", "fields", "filter", "paginated", "id", "context"]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    id: str
    context: _base_pb2.Context
    def __init__(
        self,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        id: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class FamilyReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "families", "context"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    FAMILIES_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    families: _containers.RepeatedCompositeFieldContainer[Family]
    context: _base_pb2.Context
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        families: _Optional[_Iterable[_Union[Family, _Mapping]]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class FamilyUpdateRequest(_message.Message):
    __slots__ = ["family", "context"]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family: Family
    context: _base_pb2.Context
    def __init__(
        self,
        family: _Optional[_Union[Family, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class FamilyUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "family"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    family: Family
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        family: _Optional[_Union[Family, _Mapping]] = ...,
    ) -> None: ...

class FamilyDeleteRequest(_message.Message):
    __slots__ = ["id", "context"]
    ID_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    id: str
    context: _base_pb2.Context
    def __init__(
        self, id: _Optional[str] = ..., context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...
    ) -> None: ...

class FamilyDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class Attribute(_message.Message):
    __slots__ = ["code", "name", "attribute_type", "is_common", "family", "group", "active", "extra_attribute"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_COMMON_FIELD_NUMBER: _ClassVar[int]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    EXTRA_ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    code: str
    name: str
    attribute_type: str
    is_common: bool
    family: _struct_pb2.Struct
    group: _struct_pb2.Struct
    active: _wrappers_pb2.BoolValue
    extra_attribute: _struct_pb2.Struct
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        attribute_type: _Optional[str] = ...,
        is_common: bool = ...,
        family: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        group: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        extra_attribute: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
    ) -> None: ...

class AttributeCreateRequest(_message.Message):
    __slots__ = ["family_id", "group_code", "code", "name", "attribute_type", "is_common", "extra_attribute", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_TYPE_FIELD_NUMBER: _ClassVar[int]
    IS_COMMON_FIELD_NUMBER: _ClassVar[int]
    EXTRA_ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    group_code: str
    code: str
    name: str
    attribute_type: str
    is_common: bool
    extra_attribute: _struct_pb2.Struct
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        group_code: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        attribute_type: _Optional[str] = ...,
        is_common: bool = ...,
        extra_attribute: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeCreateResponse(_message.Message):
    __slots__ = ["response_standard", "attribute"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    attribute: Attribute
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        attribute: _Optional[_Union[Attribute, _Mapping]] = ...,
    ) -> None: ...

class AttributeReadRequest(_message.Message):
    __slots__ = ["family_id", "group_code", "code", "group_by", "sort_by", "fields", "filter", "paginated", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    group_code: str
    code: str
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        group_code: _Optional[str] = ...,
        code: _Optional[str] = ...,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "attributes"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    attributes: _containers.RepeatedCompositeFieldContainer[Attribute]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        attributes: _Optional[_Iterable[_Union[Attribute, _Mapping]]] = ...,
    ) -> None: ...

class AttributeUpdateRequest(_message.Message):
    __slots__ = ["attribute", "context"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    attribute: Attribute
    context: _base_pb2.Context
    def __init__(
        self,
        attribute: _Optional[_Union[Attribute, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "attribute"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    attribute: Attribute
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        attribute: _Optional[_Union[Attribute, _Mapping]] = ...,
    ) -> None: ...

class AttributeDeleteRequest(_message.Message):
    __slots__ = ["family_id", "group_code", "code", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_CODE_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    group_code: str
    code: str
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        group_code: _Optional[str] = ...,
        code: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class Group(_message.Message):
    __slots__ = ["code", "name", "active", "family", "attributes"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    FAMILY_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    code: str
    name: str
    active: _wrappers_pb2.BoolValue
    family: _struct_pb2.Struct
    attributes: _containers.RepeatedCompositeFieldContainer[Attribute]
    def __init__(
        self,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
        family: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        attributes: _Optional[_Iterable[_Union[Attribute, _Mapping]]] = ...,
    ) -> None: ...

class GroupCreateRequest(_message.Message):
    __slots__ = ["family_id", "code", "name", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    code: str
    name: str
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        name: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupCreateResponse(_message.Message):
    __slots__ = ["response_standard", "group"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    group: Group
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        group: _Optional[_Union[Group, _Mapping]] = ...,
    ) -> None: ...

class GroupReadRequest(_message.Message):
    __slots__ = ["family_id", "code", "group_by", "sort_by", "fields", "filter", "paginated", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    code: str
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "groups"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    GROUPS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    groups: _containers.RepeatedCompositeFieldContainer[Group]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        groups: _Optional[_Iterable[_Union[Group, _Mapping]]] = ...,
    ) -> None: ...

class GroupUpdateRequest(_message.Message):
    __slots__ = ["family_id", "group", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    group: Group
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        group: _Optional[_Union[Group, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "group"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    group: Group
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        group: _Optional[_Union[Group, _Mapping]] = ...,
    ) -> None: ...

class GroupDeleteRequest(_message.Message):
    __slots__ = ["family_id", "code", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    code: str
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        code: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class GroupDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...

class AttributeVariant(_message.Message):
    __slots__ = ["attribute", "sequence", "family_id", "active"]
    ATTRIBUTE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    attribute: _struct_pb2.Struct
    sequence: int
    family_id: str
    active: _wrappers_pb2.BoolValue
    def __init__(
        self,
        attribute: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ...,
        sequence: _Optional[int] = ...,
        family_id: _Optional[str] = ...,
        active: _Optional[_Union[_wrappers_pb2.BoolValue, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantCreateRequest(_message.Message):
    __slots__ = ["family_id", "attribute_code", "sequence", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_CODE_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    attribute_code: str
    sequence: int
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        attribute_code: _Optional[str] = ...,
        sequence: _Optional[int] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantCreateResponse(_message.Message):
    __slots__ = ["response_standard", "attribute_variant"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VARIANT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    attribute_variant: AttributeVariant
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        attribute_variant: _Optional[_Union[AttributeVariant, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantReadRequest(_message.Message):
    __slots__ = ["family_id", "attribute_code", "group_by", "sort_by", "fields", "filter", "paginated", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_CODE_FIELD_NUMBER: _ClassVar[int]
    GROUP_BY_FIELD_NUMBER: _ClassVar[int]
    SORT_BY_FIELD_NUMBER: _ClassVar[int]
    FIELDS_FIELD_NUMBER: _ClassVar[int]
    FILTER_FIELD_NUMBER: _ClassVar[int]
    PAGINATED_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    attribute_code: str
    group_by: _containers.RepeatedCompositeFieldContainer[_base_pb2.GroupBy]
    sort_by: _base_pb2.SortBy
    fields: _base_pb2.Fields
    filter: _base_pb2.Filter
    paginated: _base_pb2.Paginated
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        attribute_code: _Optional[str] = ...,
        group_by: _Optional[_Iterable[_Union[_base_pb2.GroupBy, _Mapping]]] = ...,
        sort_by: _Optional[_Union[_base_pb2.SortBy, _Mapping]] = ...,
        fields: _Optional[_Union[_base_pb2.Fields, _Mapping]] = ...,
        filter: _Optional[_Union[_base_pb2.Filter, _Mapping]] = ...,
        paginated: _Optional[_Union[_base_pb2.Paginated, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantReadResponse(_message.Message):
    __slots__ = ["response_standard", "meta_data", "attribute_variants"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    META_DATA_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VARIANTS_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    meta_data: _base_pb2.MetaData
    attribute_variants: _containers.RepeatedCompositeFieldContainer[AttributeVariant]
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        meta_data: _Optional[_Union[_base_pb2.MetaData, _Mapping]] = ...,
        attribute_variants: _Optional[_Iterable[_Union[AttributeVariant, _Mapping]]] = ...,
    ) -> None: ...

class AttributeVariantUpdateRequest(_message.Message):
    __slots__ = ["code", "attribute_variant", "context"]
    CODE_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VARIANT_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    code: str
    attribute_variant: AttributeVariant
    context: _base_pb2.Context
    def __init__(
        self,
        code: _Optional[str] = ...,
        attribute_variant: _Optional[_Union[AttributeVariant, _Mapping]] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantUpdateResponse(_message.Message):
    __slots__ = ["response_standard", "attribute_variant"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_VARIANT_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    attribute_variant: AttributeVariant
    def __init__(
        self,
        response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...,
        attribute_variant: _Optional[_Union[AttributeVariant, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantDeleteRequest(_message.Message):
    __slots__ = ["family_id", "attribute_code", "context"]
    FAMILY_ID_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTE_CODE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    family_id: str
    attribute_code: str
    context: _base_pb2.Context
    def __init__(
        self,
        family_id: _Optional[str] = ...,
        attribute_code: _Optional[str] = ...,
        context: _Optional[_Union[_base_pb2.Context, _Mapping]] = ...,
    ) -> None: ...

class AttributeVariantDeleteResponse(_message.Message):
    __slots__ = ["response_standard"]
    RESPONSE_STANDARD_FIELD_NUMBER: _ClassVar[int]
    response_standard: _base_pb2.ResponseStandard
    def __init__(self, response_standard: _Optional[_Union[_base_pb2.ResponseStandard, _Mapping]] = ...) -> None: ...



import csv
from pathlib import Path

from omni.pro import redis, util
from omni.pro.config import Config
from omni.pro.database import DatabaseManager
from omni.pro.logger import LoggerTraceback, configure_logger
from omni.pro.microservice import MicroService, MicroServiceDocument
from omni.pro.protos.grpc_connector import Event, GRPClient
from omni.pro.protos.v1.users import user_pb2
from omni.pro.stack import ExitStackDocument
from omni.pro.validators import MicroServiceValidator

logger = configure_logger(name=__name__)


class LoadData(object):
    def __init__(self, base_app: Path):
        # self.redis_manager = redis.get_redis_manager()
        self.base_app = base_app
        self.manifest = self._get_manifest_ms()
        # self.context = self._get_context()
        self.microserivce = None

    def load_data(self, *args, **kwargs):
        self.redis_manager = redis.get_redis_manager()
        list_contexts = []
        with self.redis_manager.get_connection() as rc:
            tenant_codes = self.redis_manager.get_tenant_codes()
            for tenant in tenant_codes:
                user = rc.json().get(tenant, "$.user_admin")
                context = {"tenant": tenant, "user": user}
                if (not context.get("user")) or (context.get("user") and (not context.get("user")[0])):
                    context["user"] = None
                    response, success = self.create_user_admin(context, rc)
                    if not success:
                        # TODO: End process
                        continue
                    context["user"] = response.user.username
                else:
                    # TODO: Validate if user exists in database
                    context["user"] = user[0].get("username")
                db_params = self.redis_manager.get_mongodb_config(Config.SERVICE_ID, tenant)
                db_params["db"] = db_params.pop("name")
                self.db_manager = DatabaseManager(**db_params)
                db_alias = f"{tenant}_{db_params['db']}"
                if not self.manifest:
                    continue
                micro = self.load_manifest(context=context, db_alias=db_alias)
                self.load_data_micro(micro, context, db_alias)
                list_contexts.append(context)
        return list_contexts

    def create_user_admin(self, context, rc):
        values = self.load_data_dict(Path(__file__).parent / "data" / "models.user.csv")
        user = UserChannel(context)
        response, success = user.create_users(values)
        if success:
            rc.json().set(
                context.get("tenant"), "$.user_admin", {"id": response.user.id, "username": response.user.username}
            )
        return response, success

    def _get_manifest_ms(self):
        file_name = self.base_app / "__manifest__.py"
        if not file_name.exists():
            logger.warning(f"Manifest file not found {file_name}")
            return {}
        with open(file_name, "r") as f:
            data = f.read()
        return eval(data)

    def load_manifest(self, context: dict, db_alias: str):
        with ExitStackDocument(MicroServiceDocument.reference_list(), db_alias=db_alias):
            tenant = context.get("tenant")
            filters = {"code": self.manifest.get("code"), "tenant_code": tenant}
            micro: MicroServiceDocument = self.db_manager.get_document(
                db_name=None, tenant=tenant, document_class=MicroServiceDocument, **filters
            )
            self.manifest["tenant_code"] = tenant
            data_validated = MicroServiceValidator(self.base_app, micro.data if micro else []).load(
                self.manifest | {"context": context}
            )
            if not micro:
                micro = self.db_manager.create_document(
                    db_name=None, document_class=MicroServiceDocument, **data_validated
                )
            else:
                micro.data = data_validated.get("data")
                micro.save()
            self.microservice = micro
            return micro

    def load_data_dict(self, name_file):
        try:
            with open(name_file, mode="r", encoding="utf-8-sig") as csv_file:
                reader = csv.DictReader(csv_file, delimiter=";")
                for row in reader:
                    yield row
                return reader
        except FileNotFoundError as e:
            LoggerTraceback.error("File not found exception", e, logger)
        except Exception as e:
            LoggerTraceback.error("An unexpected error has occurred", e, logger)

    def load_data_micro(self, micro: MicroServiceDocument, context: dict, db_alias):
        tenant = context.get("tenant")
        for idx, file in enumerate(micro.data):
            if file.get("load"):
                continue
            name_file = self.base_app / file.get("path")
            reader = self.load_data_dict(name_file)
            models, file_py, model_str = file.get("path").split("/")[1].split(".")[:-1]
            model_str = util.to_camel_case(model_str)
            ruta_modulo = self.base_app / models / f"{file_py}.py"
            if not ruta_modulo.exists():
                logger.error(f"File not found {ruta_modulo}")
                continue
            modulo = util.load_file_module(ruta_modulo, model_str)
            if not hasattr(modulo, model_str):
                logger.error(f"Class not found {model_str} in {ruta_modulo}")
                continue
            load = False
            with ExitStackDocument(
                (doc_class := getattr(modulo, model_str)).reference_list() + MicroServiceDocument.reference_list(),
                db_alias=db_alias,
            ):
                for row in reader:
                    row = row | {"context": context}
                    self.db_manager.create_document(db_name=None, document_class=doc_class, **row)
                    if not load:
                        load = True
                attr_data = {f"set__data__{idx}__load": load}
                self.db_manager.update(micro, **attr_data)
                if load:
                    logger.info(f"Load data {micro.code} - {tenant} - {file.get('path')}")


class UserChannel(object):
    def __init__(self, context: dict) -> None:
        self.context = context
        self.service_id = MicroService.SAAS_MS_USER.value
        self.user_module_grpc = "v1.users.user_pb2_grpc"
        self.user_stub_classname = "UsersServiceStub"
        self.user_module_pb2 = "v1.users.user_pb2"

        self.event = Event(
            module_grpc=self.user_module_grpc,
            stub_classname=self.user_stub_classname,
            rpc_method="",
            module_pb2=self.user_module_pb2,
            request_class="",
            params={},
        )

    def create_users(self, list_value):
        response = user_pb2.UserCreateResponse(), False
        for value in list_value:
            self.context["user"] = self.context.get("user") or value.get("sub")
            self.event.update(
                rpc_method="UserCreate",
                request_class="UserCreateRequest",
                params={
                    "context": self.context,
                    "email": value.get("email"),
                    "email_confirm": value.get("email"),
                    "language": {"code": "01", "code_name": "CO"},
                    "name": value.get("name"),
                    "password": value.get("password"),
                    "password_confirm": value.get("password"),
                    "timezone": {"code": "01", "code_name": "CO"},
                    "username": value.get("username"),
                    "is_superuser": True,
                },
            )
            response = GRPClient(service_id=self.service_id).call_rpc_fuction(self.event)
        return response



from omni.pro.config import Config
from omni.pro.protos.grpc_connector import Event, GRPClient


class ModelRPCFucntion(object):
    def __init__(self, context: dict) -> None:
        """
        :param context: context with tenant and user\n
        Example:
        ```
        context = {"tenant": "tenant_code", "user": "user_name"}
        ```
        """
        self.context = context
        self.service_id = Config.SAAS_MS_UTILITIES
        self.module_grpc = "v1.utilities.model_pb2_grpc"
        self.stub_classname = "ModelsServiceStub"
        self.module_pb2 = "v1.utilities.model_pb2"

        self.client: GRPClient = GRPClient(self.service_id)

    def register_model(self, **params):
        event = Event(
            module_grpc=self.module_grpc,
            stub_classname=self.stub_classname,
            rpc_method="ModelCreate",
            module_pb2=self.module_pb2,
            request_class="ModelCreateRequest",
            params={"context": self.context} | params,
        )
        return self.client.call_rpc_fuction(event)
